@@ -41,6 +41,7 @@ __all__ = (
     "OperatorPropertiesKeysType",
     "OperatorType",
     "OperatorsType",
+    "PardotConnectorOperatorType",
     "PathPrefixType",
     "PrefixFormatType",
     "PrefixTypeType",
@@ -86,6 +87,7 @@ ConnectorTypeType = Literal[
     "Infornexus",
     "LookoutMetrics",
     "Marketo",
+    "Pardot",
     "Redshift",
     "S3",
     "SAPOData",
@@ -240,6 +242,22 @@ OperatorsType = Literal[
     "VALIDATE_NON_ZERO",
     "VALIDATE_NUMERIC",
 ]
+PardotConnectorOperatorType = Literal[
+    "ADDITION",
+    "DIVISION",
+    "EQUAL_TO",
+    "MASK_ALL",
+    "MASK_FIRST_N",
+    "MASK_LAST_N",
+    "MULTIPLICATION",
+    "NO_OP",
+    "PROJECTION",
+    "SUBTRACTION",
+    "VALIDATE_NON_NEGATIVE",
+    "VALIDATE_NON_NULL",
+    "VALIDATE_NON_ZERO",
+    "VALIDATE_NUMERIC",
+]
 PathPrefixType = Literal["EXECUTION_ID", "SCHEMA_VERSION"]
 PrefixFormatType = Literal["DAY", "HOUR", "MINUTE", "MONTH", "YEAR"]
 PrefixTypeType = Literal["FILENAME", "PATH", "PATH_AND_FILENAME"]
@@ -491,6 +509,7 @@ ServiceName = Literal[
     "chime-sdk-meetings",
     "chime-sdk-messaging",
     "chime-sdk-voice",
+    "cleanrooms",
     "cloud9",
     "cloudcontrol",
     "clouddirectory",
@@ -616,11 +635,13 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "kendra-ranking",
     "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
     "kinesis-video-signaling",
+    "kinesis-video-webrtc-storage",
     "kinesisanalytics",
     "kinesisanalyticsv2",
     "kinesisvideo",
@@ -632,6 +653,7 @@ ServiceName = Literal[
     "lexv2-models",
     "lexv2-runtime",
     "license-manager",
+    "license-manager-linux-subscriptions",
     "license-manager-user-subscriptions",
     "lightsail",
     "location",
