@@ -34,6 +34,7 @@ from .literals import (
     OperatorPropertiesKeysType,
     OperatorsType,
     OperatorType,
+    PardotConnectorOperatorType,
     PathPrefixType,
     PrefixFormatType,
     PrefixTypeType,
@@ -99,6 +100,7 @@ __all__ = (
     "DynatraceConnectorProfilePropertiesTypeDef",
     "InforNexusConnectorProfilePropertiesTypeDef",
     "MarketoConnectorProfilePropertiesTypeDef",
+    "PardotConnectorProfilePropertiesTypeDef",
     "RedshiftConnectorProfilePropertiesTypeDef",
     "SalesforceConnectorProfilePropertiesTypeDef",
     "ServiceNowConnectorProfilePropertiesTypeDef",
@@ -139,6 +141,7 @@ __all__ = (
     "RegistrationOutputTypeDef",
     "OAuth2CustomParameterTypeDef",
     "OAuthPropertiesTypeDef",
+    "PardotSourcePropertiesTypeDef",
     "PrefixConfigTypeDef",
     "S3InputFormatConfigTypeDef",
     "SuccessResponseHandlingConfigTypeDef",
@@ -163,6 +166,7 @@ __all__ = (
     "MarketoConnectorProfileCredentialsTypeDef",
     "OAuth2CredentialsTypeDef",
     "OAuthCredentialsTypeDef",
+    "PardotConnectorProfileCredentialsTypeDef",
     "SalesforceConnectorProfileCredentialsTypeDef",
     "SlackConnectorProfileCredentialsTypeDef",
     "ZendeskConnectorProfileCredentialsTypeDef",
@@ -451,6 +455,7 @@ ConnectorOperatorTypeDef = TypedDict(
         "Zendesk": ZendeskConnectorOperatorType,
         "SAPOData": SAPODataConnectorOperatorType,
         "CustomConnector": OperatorType,
+        "Pardot": PardotConnectorOperatorType,
     },
     total=False,
 )
@@ -555,6 +560,16 @@ MarketoConnectorProfilePropertiesTypeDef = TypedDict(
     },
 )
 
+PardotConnectorProfilePropertiesTypeDef = TypedDict(
+    "PardotConnectorProfilePropertiesTypeDef",
+    {
+        "instanceUrl": str,
+        "isSandboxEnvironment": bool,
+        "businessUnitId": str,
+    },
+    total=False,
+)
+
 _RequiredRedshiftConnectorProfilePropertiesTypeDef = TypedDict(
     "_RequiredRedshiftConnectorProfilePropertiesTypeDef",
     {
@@ -1061,6 +1076,13 @@ OAuthPropertiesTypeDef = TypedDict(
     },
 )
 
+PardotSourcePropertiesTypeDef = TypedDict(
+    "PardotSourcePropertiesTypeDef",
+    {
+        "object": str,
+    },
+)
+
 PrefixConfigTypeDef = TypedDict(
     "PrefixConfigTypeDef",
     {
@@ -1290,6 +1312,7 @@ ConnectorMetadataTypeDef = TypedDict(
         "CustomerProfiles": Dict[str, Any],
         "Honeycode": HoneycodeMetadataTypeDef,
         "SAPOData": Dict[str, Any],
+        "Pardot": Dict[str, Any],
     },
     total=False,
 )
@@ -1387,6 +1410,17 @@ class OAuthCredentialsTypeDef(_RequiredOAuthCredentialsTypeDef, _OptionalOAuthCr
     pass
 
 
+PardotConnectorProfileCredentialsTypeDef = TypedDict(
+    "PardotConnectorProfileCredentialsTypeDef",
+    {
+        "accessToken": str,
+        "refreshToken": str,
+        "oAuthRequest": ConnectorOAuthRequestTypeDef,
+        "clientCredentialsArn": str,
+    },
+    total=False,
+)
+
 SalesforceConnectorProfileCredentialsTypeDef = TypedDict(
     "SalesforceConnectorProfileCredentialsTypeDef",
     {
@@ -2096,6 +2130,7 @@ ConnectorProfilePropertiesTypeDef = TypedDict(
         "Zendesk": ZendeskConnectorProfilePropertiesTypeDef,
         "SAPOData": SAPODataConnectorProfilePropertiesTypeDef,
         "CustomConnector": CustomConnectorProfilePropertiesTypeDef,
+        "Pardot": PardotConnectorProfilePropertiesTypeDef,
     },
     total=False,
 )
@@ -2163,6 +2198,7 @@ SourceConnectorPropertiesTypeDef = TypedDict(
         "Zendesk": ZendeskSourcePropertiesTypeDef,
         "SAPOData": SAPODataSourcePropertiesTypeDef,
         "CustomConnector": CustomConnectorSourcePropertiesTypeDef,
+        "Pardot": PardotSourcePropertiesTypeDef,
     },
     total=False,
 )
@@ -2207,6 +2243,7 @@ ConnectorProfileCredentialsTypeDef = TypedDict(
         "Zendesk": ZendeskConnectorProfileCredentialsTypeDef,
         "SAPOData": SAPODataConnectorProfileCredentialsTypeDef,
         "CustomConnector": CustomConnectorProfileCredentialsTypeDef,
+        "Pardot": PardotConnectorProfileCredentialsTypeDef,
     },
     total=False,
 )
